@@ -12,12 +12,12 @@
 
 using namespace IncidenceEditorNG;
 
-class IncidenceCompletionPriority::Private
+class IncidenceEditorNG::IncidenceCompletionPriorityPrivate
 {
     IncidenceCompletionPriority *const q;
 
 public:
-    explicit Private(IncidenceCompletionPriority *parent)
+    explicit IncidenceCompletionPriorityPrivate(IncidenceCompletionPriority *parent)
         : q(parent)
     {
     }
@@ -30,7 +30,7 @@ public: // slots
     void sliderValueChanged(int);
 };
 
-void IncidenceCompletionPriority::Private::sliderValueChanged(int value)
+void IncidenceCompletionPriorityPrivate::sliderValueChanged(int value)
 {
     if (q->sender() == mUi->mCompletionSlider) {
         mOrigPercentCompleted = -1;
@@ -42,7 +42,7 @@ void IncidenceCompletionPriority::Private::sliderValueChanged(int value)
 
 IncidenceCompletionPriority::IncidenceCompletionPriority(Ui::EventOrTodoDesktop *ui)
     : IncidenceEditor()
-    , d(new Private(this))
+    , d(new IncidenceCompletionPriorityPrivate(this))
 {
     Q_ASSERT(ui != nullptr);
     setObjectName(QStringLiteral("IncidenceCompletionPriority"));
@@ -56,16 +56,13 @@ IncidenceCompletionPriority::IncidenceCompletionPriority(Ui::EventOrTodoDesktop
     d->mUi->mCompletedLabel->setMinimumWidth(metrics.boundingRect(QStringLiteral("100%")).width());
     d->mUi->mTaskSeparator->hide();
 
-    connect(d->mUi->mCompletionSlider, qOverload<int>(&QSlider::valueChanged), this, [this](int val) {
+    connect(d->mUi->mCompletionSlider, &QSlider::valueChanged, this, [this](int val) {
         d->sliderValueChanged(val);
     });
-    connect(d->mUi->mPriorityCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, &IncidenceCompletionPriority::checkDirtyStatus);
+    connect(d->mUi->mPriorityCombo, &QComboBox::currentIndexChanged, this, &IncidenceCompletionPriority::checkDirtyStatus);
 }
 
-IncidenceCompletionPriority::~IncidenceCompletionPriority()
-{
-    delete d;
-}
+IncidenceCompletionPriority::~IncidenceCompletionPriority() = default;
 
 void IncidenceCompletionPriority::load(const KCalendarCore::Incidence::Ptr &incidence)
 {
